@@ -17,6 +17,7 @@
 import feedparser, pickle, os, sys, twitter, urllib
 from ConfigParser import ConfigParser, NoOptionError
 import readrss
+import re
 import time
 from pprint import pprint
 from tinyurl import tiny
@@ -30,15 +31,29 @@ class Feed2Twitter(object):
         self.username=username
         self.passwd=passwd
         self.twApi=twitter.Api(username=self.username, password=self.passwd)
+        self.set_attr_headers()
         self.rss = readrss.parse(url)
+    
+    def set_attr_headers(self):
+        return
+        self.api.SetUserAgent('"feed2twitter/0.2"')
+    
+
+    def strip_tags(self,value):
+        "Return the given HTML with all tags stripped."
+        txt = re.sub(r'<[^>]*?>', '', value.replace('\t','').replace('\n','')) 
+        return txt.replace('(Comments)','')
 
     def twitIt(self, items):
         oldItems=pItems=0
         for it in list(items):
-            if mode == 'title':
+            if self.mode == 'title':
                 txt=it["title"][0:114] +" "+tiny(it["link"])
-            elif mode == 'text':
-                txt = it['text'][0:140]
+            elif self.mode == 'text':
+                try:
+                    txt = self.strip_tags(it.content[0].value)[0:140]
+                except:
+                    txt = self.strip_tags(it.summary)[0:140]
             else:
                 txt = it['title'][0:144] + " " + tiny(it['link'])
             try:
